@@ -39,17 +39,17 @@
 #include "ros/ros.h"
 #include <ros/package.h>
 
-#include <OgreRoot.h>
-#include <OgreRenderWindow.h>
-#include <OgreSceneManager.h>
-#include <OgreViewport.h>
-#include <OgreRectangle2D.h>
-#include <OgreMaterial.h>
-#include <OgreMaterialManager.h>
-#include <OgreTextureUnitState.h>
-#include <OgreSharedPtr.h>
-#include <OgreTechnique.h>
-#include <OgreSceneNode.h>
+#include <OGRE/OgreRoot.h>
+#include <OGRE/OgreRenderWindow.h>
+#include <OGRE/OgreSceneManager.h>
+#include <OGRE/OgreViewport.h>
+#include <OGRE/OgreRectangle2D.h>
+#include <OGRE/OgreMaterial.h>
+#include <OGRE/OgreMaterialManager.h>
+#include <OGRE/OgreTextureUnitState.h>
+#include <OGRE/OgreSharedPtr.h>
+#include <OGRE/OgreTechnique.h>
+#include <OGRE/OgreSceneNode.h>
 
 #include "image_view.h"
 
