@@ -46,8 +46,8 @@
 #include <boost/foreach.hpp>
 #include <boost/shared_ptr.hpp>
 
-#include <OgreSceneNode.h>
-#include <OgreSceneManager.h>
+#include <OGRE/OgreSceneNode.h>
+#include <OGRE/OgreSceneManager.h>
 
 #include <image_transport/camera_common.h>
 #include <image_transport/subscriber_plugin.h>
@@ -159,10 +159,6 @@ void DepthCloudDisplay::onInitialize()
   updateUseAutoSize();
   updateUseOcclusionCompensation();
 
-  // PointCloudCommon sets up a callback queue with a thread for each
-  // instance.  Use that for processing incoming messages.
-  threaded_nh_.setCallbackQueue(pointcloud_common_->getCallbackQueue());
-
   // Scan for available transport plugins
   scanForTransportSubscriberPlugins();
 
@@ -367,16 +363,12 @@ void DepthCloudDisplay::unsubscribe()
 
 void DepthCloudDisplay::clear()
 {
-  boost::mutex::scoped_lock lock(mutex_);
-
   pointcloud_common_->reset();
 }
 
 
 void DepthCloudDisplay::update(float wall_dt, float ros_dt)
 {
-  boost::mutex::scoped_lock lock(mutex_);
-
   pointcloud_common_->update(wall_dt, ros_dt);
 }
 
