@@ -30,21 +30,21 @@
 #ifndef INTERACTIVE_MARKER_CONTROL_H_
 #define INTERACTIVE_MARKER_CONTROL_H_
 
-
 #ifndef Q_MOC_RUN
 #include <boost/shared_ptr.hpp>
 #include <boost/enable_shared_from_this.hpp>
 
-#include <OgreRay.h>
-#include <OgreVector3.h>
-#include <OgreQuaternion.h>
-#include <OgreSceneManager.h>
+#include <OGRE/OgreRay.h>
+#include <OGRE/OgreVector3.h>
+#include <OGRE/OgreQuaternion.h>
+#include <OGRE/OgreSceneManager.h>
 #endif
 
 #include <QCursor>
 
 #include <visualization_msgs/InteractiveMarkerControl.h>
 
+#include <rviz/windows_compat.h>
 #include <rviz/default_plugin/markers/marker_base.h>
 #include <rviz/selection/forwards.h>
 #include <rviz/viewport_mouse_event.h>
