@@ -36,9 +36,9 @@
 
 #include <rviz/ogre_helpers/billboard_line.h>
 
-#include <OgreVector3.h>
-#include <OgreQuaternion.h>
-#include <OgreSceneNode.h>
+#include <OGRE/OgreVector3.h>
+#include <OGRE/OgreQuaternion.h>
+#include <OGRE/OgreSceneNode.h>
 
 namespace rviz
 {
