@@ -27,9 +27,9 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <OgreColourValue.h>
-#include <OgreMatrix4.h>
-#include <OgreVector3.h>
+#include <OGRE/OgreColourValue.h>
+#include <OGRE/OgreMatrix4.h>
+#include <OGRE/OgreVector3.h>
 
 #include <rviz/properties/bool_property.h>
 #include <rviz/properties/color_property.h>
@@ -263,8 +263,8 @@ void IntensityPCTransformer::updateChannels(const sensor_msgs::PointCloud2ConstP
 void IntensityPCTransformer::updateAutoComputeIntensityBounds()
 {
   bool auto_compute = auto_compute_intensity_bounds_property_->getBool();
-  min_intensity_property_->setHidden(auto_compute);
-  max_intensity_property_->setHidden(auto_compute);
+  min_intensity_property_->setReadOnly(auto_compute);
+  max_intensity_property_->setReadOnly(auto_compute);
   if (auto_compute)
   {
     disconnect(min_intensity_property_, SIGNAL(changed()), this, SIGNAL(needRetransform()));
