@@ -29,8 +29,8 @@
 
 #include <boost/bind.hpp>
 
-#include <OgreSceneNode.h>
-#include <OgreSceneManager.h>
+#include <OGRE/OgreSceneNode.h>
+#include <OGRE/OgreSceneManager.h>
 
 #include <rviz/display_context.h>
 #include <rviz/frame_manager.h>
@@ -370,12 +370,8 @@ void TFDisplay::updateFrames()
   S_FrameInfo current_frames;
 
   {
-    V_string::iterator it = frames.begin();
-    V_string::iterator end = frames.end();
-    for (; it != end; ++it)
+    for (const std::string& frame : frames)
     {
-      const std::string& frame = *it;
-
       if (frame.empty())
       {
         continue;
@@ -588,34 +584,6 @@ void TFDisplay::updateFrame(FrameInfo* frame)
   bool has_parent = tf->_getParent(frame->name_, ros::Time(), frame->parent_);
   if (has_parent)
   {
-    // If this frame has no tree property or the parent has changed,
-    if (!frame->tree_property_ || old_parent != frame->parent_)
-    {
-      // Look up the new parent.
-      M_FrameInfo::iterator parent_it = frames_.find(frame->parent_);
-      if (parent_it != frames_.end())
-      {
-        FrameInfo* parent = parent_it->second;
-
-        // If the parent has a tree property, make a new tree property for this frame.
-        if (parent->tree_property_)
-        {
-          if (!frame->tree_property_)
-          {
-            frame->tree_property_ = new Property(QString::fromStdString(frame->name_), QVariant(), "",
-                                                 parent->tree_property_);
-          }
-          else
-          {
-            frame->tree_property_->setParent(parent->tree_property_);
-            frame->tree_property_->setName(QString::fromStdString(frame->name_));
-            frame->tree_property_->setValue(QVariant());
-            frame->tree_property_->setDescription("");
-          }
-        }
-      }
-    }
-
     geometry_msgs::TransformStamped transform;
     try
     {
@@ -680,25 +648,37 @@ void TFDisplay::updateFrame(FrameInfo* frame)
   }
   else
   {
-    if (!frame->tree_property_ || old_parent != frame->parent_)
-    {
-      if (!frame->tree_property_)
-      {
-        frame->tree_property_ =
-            new Property(QString::fromStdString(frame->name_), QVariant(), "", tree_category_);
-      }
-      else
-      {
-        frame->tree_property_->setName(QString::fromStdString(frame->name_));
-        frame->tree_property_->setValue(QVariant());
-        frame->tree_property_->setDescription("");
-        frame->tree_property_->setParent(tree_category_);
-      }
-    }
-
     frame->parent_arrow_->getSceneNode()->setVisible(false);
   }
 
+  // If this frame has no tree property or the parent has changed,
+  if (!frame->tree_property_ || old_parent != frame->parent_)
+  {
+    // Look up the new parent.
+    FrameInfo* parent = has_parent ? getFrameInfo(frame->parent_) : nullptr;
+    // Retrieve tree property to add the new child at
+    rviz::Property* parent_tree_property = has_parent ? nullptr : tree_category_;
+    if (parent && parent->tree_property_)
+      parent_tree_property = parent->tree_property_;
+    else if (has_parent) // otherwise reset parent_ to retry if the parent property was created
+      frame->parent_ = old_parent;
+
+    // If the parent has a tree property, make a new tree property for this frame.
+    if (!parent_tree_property)
+      ;                              // nothing more to do
+    else if (!frame->tree_property_) // create new property
+    {
+      frame->tree_property_ =
+          new Property(QString::fromStdString(frame->name_), QVariant(), "", parent_tree_property);
+    }
+    else // update property
+    {
+      // re-parent the tree property
+      frame->tree_property_->getParent()->takeChild(frame->tree_property_);
+      parent_tree_property->addChild(frame->tree_property_);
+    }
+  }
+
   frame->parent_property_->setStdString(frame->parent_);
   frame->selection_handler_->setParentName(frame->parent_);
 }
