@@ -28,24 +28,28 @@
  */
 
 #include "mesh_loader.h"
+#include <OGRE/OgrePrerequisites.h>
 #include <resource_retriever/retriever.h>
 
 #include <boost/filesystem.hpp>
 #include <boost/algorithm/string.hpp>
 
-#include <OgreMeshManager.h>
-#include <OgreTextureManager.h>
-#include <OgreMaterialManager.h>
-#include <OgreTexture.h>
-#include <OgrePass.h>
-#include <OgreTechnique.h>
-#include <OgreMaterial.h>
-#include <OgreTextureUnitState.h>
-#include <OgreMeshSerializer.h>
-#include <OgreSubMesh.h>
-#include <OgreHardwareBufferManager.h>
-#include <OgreSharedPtr.h>
-#include <OgreTechnique.h>
+#include <OGRE/OgreSkeleton.h>
+#include <OGRE/OgreSkeletonManager.h>
+#include <OGRE/OgreSkeletonSerializer.h>
+#include <OGRE/OgreMeshManager.h>
+#include <OGRE/OgreTextureManager.h>
+#include <OGRE/OgreMaterialManager.h>
+#include <OGRE/OgreTexture.h>
+#include <OGRE/OgrePass.h>
+#include <OGRE/OgreTechnique.h>
+#include <OGRE/OgreMaterial.h>
+#include <OGRE/OgreTextureUnitState.h>
+#include <OGRE/OgreMeshSerializer.h>
+#include <OGRE/OgreSubMesh.h>
+#include <OGRE/OgreHardwareBufferManager.h>
+#include <OGRE/OgreSharedPtr.h>
+#include <OGRE/OgreTechnique.h>
 
 #include <tinyxml2.h>
 
@@ -56,6 +60,7 @@
 #include <assimp/postprocess.h>
 #include <assimp/IOStream.hpp>
 #include <assimp/IOSystem.hpp>
+#include <boost/filesystem/operations.hpp>
 
 namespace fs = boost::filesystem;
 
@@ -217,29 +222,28 @@ void buildMesh(const aiScene* scene,
                const Ogre::MeshPtr& mesh,
                Ogre::AxisAlignedBox& aabb,
                float& radius,
-               const float scale,
-               std::vector<Ogre::MaterialPtr>& material_table)
+               std::vector<Ogre::MaterialPtr>& material_table,
+               aiMatrix4x4 transform = aiMatrix4x4())
 {
   if (!node)
-  {
     return;
-  }
 
-  aiMatrix4x4 transform = node->mTransformation;
-  aiNode* pnode = node->mParent;
-  while (pnode)
+  if (node->mParent == nullptr)
   {
-    // Don't convert to y-up orientation, which is what the root node in
-    // Assimp does
-    if (pnode->mParent != nullptr)
-      transform = pnode->mTransformation * transform;
-    pnode = pnode->mParent;
+    // Use root node's transform
+    transform = node->mTransformation;
+    // but don't rotate to y-up orientation, which is *sometimes* done in assimp's root node
+    aiVector3D scaling, axis, pos;
+    float angle;
+    transform.Decompose(scaling, axis, angle, pos);
+    // drop rotation, but keep scaling and position
+    transform = aiMatrix4x4(scaling, aiQuaternion(), pos);
   }
+  else
+    transform *= node->mTransformation;
 
+  // rotation (+scaling) part of transform applied to normals
   aiMatrix3x3 rotation(transform);
-  aiMatrix3x3 inverse_transpose_rotation(rotation);
-  inverse_transpose_rotation.Inverse();
-  inverse_transpose_rotation.Transpose();
 
   for (uint32_t i = 0; i < node->mNumMeshes; i++)
   {
@@ -287,7 +291,6 @@ void buildMesh(const aiScene* scene,
     {
       aiVector3D p = input_mesh->mVertices[j];
       p *= transform;
-      p *= scale;
       *vertices++ = p.x;
       *vertices++ = p.y;
       *vertices++ = p.z;
@@ -302,7 +305,8 @@ void buildMesh(const aiScene* scene,
 
       if (input_mesh->HasNormals())
       {
-        aiVector3D n = inverse_transpose_rotation * input_mesh->mNormals[j];
+        aiVector3D n = input_mesh->mNormals[j];
+        n *= rotation;
         n.Normalize();
         *vertices++ = n.x;
         *vertices++ = n.y;
@@ -381,7 +385,7 @@ void buildMesh(const aiScene* scene,
 
   for (uint32_t i = 0; i < node->mNumChildren; ++i)
   {
-    buildMesh(scene, node->mChildren[i], mesh, aabb, radius, scale, material_table);
+    buildMesh(scene, node->mChildren[i], mesh, aabb, radius, material_table, transform);
   }
 }
 
@@ -571,73 +575,6 @@ void loadMaterials(const std::string& resource_path,
   }
 }
 
-
-/*@brief - Get the scaling from units used in this mesh file to meters.
-
-  This function applies only to Collada files. It is necessary because
-  ASSIMP does not currently expose an api to retrieve the scaling factor.
-
-  @Param[in] resource_path   -   The url of a resource containing a mesh.
-
-  @Returns The scaling factor that converts the mesh to meters. Returns 1.0
-  for meshes which do not explicitly encode such a scaling.
-
-*/
-
-float getMeshUnitRescale(const std::string& resource_path)
-{
-  float unit_scale(1.0);
-
-  // Try to read unit to meter conversion ratio from mesh. Only valid in Collada XML formats.
-  tinyxml2::XMLDocument xmlDoc;
-  resource_retriever::Retriever retriever;
-  resource_retriever::MemoryResource res;
-  try
-  {
-    res = retriever.get(resource_path);
-  }
-  catch (resource_retriever::Exception& e)
-  {
-    ROS_ERROR("%s", e.what());
-    return unit_scale;
-  }
-
-  if (res.size == 0)
-  {
-    return unit_scale;
-  }
-
-
-  // Use the resource retriever to get the data.
-  const char* data = reinterpret_cast<const char*>(res.data.get());
-  // As the data pointer provided by resource retriever is not null-terminated, also pass res.size
-  xmlDoc.Parse(data, res.size);
-
-  // Find the appropriate element if it exists
-  if (!xmlDoc.Error())
-  {
-    tinyxml2::XMLElement* colladaXml = xmlDoc.FirstChildElement("COLLADA");
-    if (colladaXml)
-    {
-      tinyxml2::XMLElement* assetXml = colladaXml->FirstChildElement("asset");
-      if (assetXml)
-      {
-        tinyxml2::XMLElement* unitXml = assetXml->FirstChildElement("unit");
-        if (unitXml && unitXml->Attribute("meter"))
-        {
-          // Failing to convert leaves unit_scale as the default.
-          if (unitXml->QueryFloatAttribute("meter", &unit_scale) != 0)
-            ROS_WARN_STREAM("getMeshUnitRescale::Failed to convert unit element meter attribute to "
-                            "determine scaling. unit element: "
-                            << unitXml->GetText());
-        }
-      }
-    }
-  }
-  return unit_scale;
-}
-
-
 Ogre::MeshPtr meshFromAssimpScene(const std::string& name, const aiScene* scene)
 {
   if (!scene->HasMeshes())
@@ -654,8 +591,7 @@ Ogre::MeshPtr meshFromAssimpScene(const std::string& name, const aiScene* scene)
 
   Ogre::AxisAlignedBox aabb(Ogre::AxisAlignedBox::EXTENT_NULL);
   float radius = 0.0f;
-  float scale = getMeshUnitRescale(name);
-  buildMesh(scene, scene->mRootNode, mesh, aabb, radius, scale, material_table);
+  buildMesh(scene, scene->mRootNode, mesh, aabb, radius, material_table);
 
   mesh->_setBounds(aabb);
   mesh->_setBoundingSphereRadius(radius);
@@ -699,6 +635,7 @@ Ogre::MeshPtr loadMeshFromResource(const std::string& resource_path)
       {
         return Ogre::MeshPtr();
       }
+      loadSkeletonFromResource(resource_path); // load skeleton to the resource manager
 
       Ogre::MeshSerializer ser;
       Ogre::DataStreamPtr stream(new Ogre::MemoryDataStream(res.data.get(), res.size));
@@ -729,4 +666,48 @@ Ogre::MeshPtr loadMeshFromResource(const std::string& resource_path)
   return Ogre::MeshPtr();
 }
 
+// Try to load .skeleton file co-located with a .mesh file
+Ogre::SkeletonPtr loadSkeletonFromResource(const std::string& resource_path)
+{
+  std::string skeleton_resource_path = resource_path.substr(0, resource_path.length() - 4);
+  skeleton_resource_path.append("skeleton");
+
+  if (Ogre::SkeletonManager::getSingleton().resourceExists(skeleton_resource_path))
+  {
+    return Ogre::SkeletonManager::getSingleton().getByName(skeleton_resource_path);
+  }
+  else
+  {
+    resource_retriever::Retriever retriever;
+    resource_retriever::MemoryResource res;
+    try
+    {
+      res = retriever.get(skeleton_resource_path);
+    }
+    catch (resource_retriever::Exception& e)
+    { // often the .skeleton file will not exist -> debug msg only
+      ROS_DEBUG("%s", e.what());
+      return Ogre::SkeletonPtr();
+    }
+
+    if (res.size == 0)
+    {
+      return Ogre::SkeletonPtr();
+    }
+
+    fs::path skeleton_path(skeleton_resource_path);
+
+    Ogre::SkeletonSerializer ser;
+    Ogre::DataStreamPtr stream(new Ogre::MemoryDataStream(res.data.get(), res.size));
+    Ogre::SkeletonPtr skeleton = Ogre::SkeletonManager::getSingleton().create(
+        skeleton_path.filename().string().c_str(),
+        Ogre::ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME, true);
+    ser.importSkeleton(stream, skeleton.get());
+
+    return skeleton;
+  }
+
+  return Ogre::SkeletonPtr();
+}
+
 } // namespace rviz
