@@ -38,13 +38,13 @@
 
 #include <vector>
 
-#include <OgrePrerequisites.h>
-#include <OgreColourValue.h>
+#include <OGRE/OgrePrerequisites.h>
+#include <OGRE/OgreColourValue.h>
 
 namespace Ogre
 {
 class Any;
-}
+} // namespace Ogre
 
 namespace rviz
 {
