@@ -29,13 +29,13 @@
 
 #include "billboard_line.h"
 
-#include <OgreSceneManager.h>
-#include <OgreSceneNode.h>
-#include <OgreVector3.h>
-#include <OgreQuaternion.h>
-#include <OgreBillboardChain.h>
-#include <OgreMaterialManager.h>
-#include <OgreTechnique.h>
+#include <OGRE/OgreSceneManager.h>
+#include <OGRE/OgreSceneNode.h>
+#include <OGRE/OgreVector3.h>
+#include <OGRE/OgreQuaternion.h>
+#include <OGRE/OgreBillboardChain.h>
+#include <OGRE/OgreMaterialManager.h>
+#include <OGRE/OgreTechnique.h>
 
 #include <sstream>
 
@@ -72,7 +72,6 @@ BillboardLine::BillboardLine(Ogre::SceneManager* scene_manager, Ogre::SceneNode*
   material_->getTechnique(0)->setLightingEnabled(false);
 
   setNumLines(num_lines_);
-  setMaxPointsPerLine(max_points_per_line_);
 }
 
 BillboardLine::~BillboardLine()
@@ -169,9 +168,20 @@ void BillboardLine::setupChains()
 
 void BillboardLine::setMaxPointsPerLine(uint32_t max)
 {
-  max_points_per_line_ = max;
-
-  setupChains();
+  if (max <= MAX_ELEMENTS)
+  {
+    max_points_per_line_ = max;
+    setupChains();
+  }
+  else // need to split points across several lines
+  {
+    ROS_ASSERT(num_lines_ == 1);
+    max_points_per_line_ = MAX_ELEMENTS;
+    num_lines_ = max / MAX_ELEMENTS;
+    if (max % MAX_ELEMENTS != 0)
+      ++num_lines_;
+    setNumLines(num_lines_);
+  }
 }
 
 void BillboardLine::setNumLines(uint32_t num)
@@ -202,18 +212,21 @@ void BillboardLine::addPoint(const Ogre::Vector3& point)
 
 void BillboardLine::addPoint(const Ogre::Vector3& point, const Ogre::ColourValue& color)
 {
-  ++num_elements_[current_line_];
-  ++total_elements_;
-
-  ROS_ASSERT(num_elements_[current_line_] <= max_points_per_line_);
-
   ++elements_in_current_chain_;
   if (elements_in_current_chain_ > MAX_ELEMENTS)
   {
     ++current_chain_;
     elements_in_current_chain_ = 1;
+
+    if (max_points_per_line_ == MAX_ELEMENTS)
+      newLine();
   }
 
+  ++num_elements_[current_line_];
+  ++total_elements_;
+
+  ROS_ASSERT(num_elements_[current_line_] <= max_points_per_line_);
+
   Ogre::BillboardChain::Element e;
   e.position = point;
   e.width = width_;
