@@ -32,10 +32,9 @@
 
 #include "object.h"
 
-#include <OgreSceneNode.h>
-#include <OgreMaterial.h>
-#include <OgreSharedPtr.h>
-#include <OgrePrerequisites.h>
+#include <OGRE/OgreSceneNode.h>
+#include <OGRE/OgreMaterial.h>
+#include <OGRE/OgreSharedPtr.h>
 
 namespace Ogre
 {
