@@ -40,17 +40,22 @@
  */
 
 #include "movable_text.h"
+#include <rviz/ogre_helpers/version_check.h>
 
-#include <OgreVector3.h>
-#include <OgreQuaternion.h>
-#include <OgreRoot.h>
-#include <OgreCamera.h>
-#include <OgreSceneNode.h>
-#include <OgreMaterialManager.h>
-#include <OgreHardwareBufferManager.h>
-#include <OgreFontManager.h>
-#include <OgreFont.h>
-#include <OgreUTFString.h>
+#include <OGRE/OgreVector3.h>
+#include <OGRE/OgreQuaternion.h>
+#include <OGRE/OgreRoot.h>
+#include <OGRE/OgreCamera.h>
+#include <OGRE/OgreSceneNode.h>
+#include <OGRE/OgreMaterialManager.h>
+#include <OGRE/OgreHardwareBufferManager.h>
+#include <OGRE/Overlay/OgreFontManager.h>
+#include <OGRE/Overlay/OgreFont.h>
+#if OGRE_VERSION < OGRE_VERSION_CHECK(1, 12, 0)
+#include <OGRE/OgreUTFString.h>
+#else
+#include <OGRE/Overlay/OgreUTFString.h>
+#endif
 
 #include <sstream>
 
@@ -237,7 +242,7 @@ void MovableText::_setupGeometry()
     mUpdateColors = true;
   }
 
-  if (utfCaption.empty())
+  if (vertexCount == 0)
   {
     return;
   }
