@@ -29,7 +29,7 @@
 #ifndef QUATERNION_PROPERTY_H
 #define QUATERNION_PROPERTY_H
 
-#include <OgreQuaternion.h>
+#include <OGRE/OgreQuaternion.h>
 
 #include <rviz/properties/property.h>
 
