@@ -36,10 +36,10 @@
 #include <QObject>
 
 #ifndef Q_MOC_RUN
-#include <OgreVector3.h>
-#include <OgreQuaternion.h>
-#include <OgreAny.h>
-#include <OgreMaterial.h>
+#include <OGRE/OgreVector3.h>
+#include <OGRE/OgreQuaternion.h>
+#include <OGRE/OgreAny.h>
+#include <OGRE/OgreMaterial.h>
 #endif
 
 #include <urdf/model.h>
@@ -48,7 +48,7 @@
 #include <rviz/ogre_helpers/object.h>
 #include <rviz/selection/forwards.h>
 
-#include <OgrePrerequisites.h>
+#include <OGRE/OgrePrerequisites.h>
 
 namespace Ogre
 {
