@@ -43,12 +43,12 @@
 #include <boost/unordered_map.hpp>
 #include <boost/thread/recursive_mutex.hpp>
 
-#include <OgreTexture.h>
-#include <OgreMaterial.h>
-#include <OgreMaterialManager.h>
-#include <OgreMovableObject.h>
-#include <OgreRenderQueueListener.h>
-#include <OgreSharedPtr.h>
+#include <OGRE/OgreTexture.h>
+#include <OGRE/OgreMaterial.h>
+#include <OGRE/OgreMaterialManager.h>
+#include <OGRE/OgreMovableObject.h>
+#include <OGRE/OgreRenderQueueListener.h>
+#include <OGRE/OgreSharedPtr.h>
 #endif
 
 #include <vector>
