@@ -33,9 +33,9 @@
 #include <boost/program_options.hpp>
 #include <boost/filesystem.hpp>
 
-#include <OgreMaterialManager.h>
-#include <OgreGpuProgramManager.h>
-#include <OgreHighLevelGpuProgramManager.h>
+#include <OGRE/OgreMaterialManager.h>
+#include <OGRE/OgreGpuProgramManager.h>
+#include <OGRE/OgreHighLevelGpuProgramManager.h>
 #include <std_srvs/Empty.h>
 
 #ifdef Q_OS_MAC
@@ -135,20 +135,24 @@ bool VisualizerApp::init(int argc, char** argv)
     int force_gl_version = 0;
 
     po::options_description options;
-    options.add_options()("help,h", "Produce this help message")(
-        "splash-screen,s", po::value<std::string>(&splash_path),
-        "A custom splash-screen image to display")("help-file", po::value<std::string>(&help_path),
-                                                   "A custom html file to show as the help screen")(
-        "display-config,d", po::value<std::string>(&display_config),
-        "A display config file (.rviz) to load")("fullscreen", "Trigger fullscreen display")(
-        "fixed-frame,f", po::value<std::string>(&fixed_frame), "Set the fixed frame")(
-        "ogre-log,l", "Enable the Ogre.log file (output in cwd) and console output.")(
-        "in-mc-wrapper", "Signal that this is running inside a master-chooser wrapper")(
-        "opengl", po::value<int>(&force_gl_version),
-        "Force OpenGL version (use '--opengl 210' for OpenGL 2.1 compatibility mode)")(
-        "disable-anti-aliasing", "Prevent rviz from trying to use anti-aliasing when rendering.")(
-        "no-stereo", "Disable the use of stereo rendering.")("verbose,v", "Enable debug visualizations")(
-        "log-level-debug", "Sets the ROS logger level to debug.");
+    options.add_options() // clang-format off
+      ("help,h", "Produce this help message")
+      ("splash-screen,s", po::value<std::string>(&splash_path),
+       "A custom splash-screen image to display")
+      ("help-file", po::value<std::string>(&help_path),
+       "A custom html file to show as the help screen")
+      ("display-config,d", po::value<std::string>(&display_config),
+       "A display config file (.rviz) to load")
+      ("fullscreen", "Trigger fullscreen display")
+      ("fixed-frame,f", po::value<std::string>(&fixed_frame), "Set the fixed frame")
+      ("ogre-log,l", "Enable the Ogre.log file (output in cwd) and console output.")
+      ("in-mc-wrapper", "Signal that this is running inside a master-chooser wrapper")
+      ("opengl", po::value<int>(&force_gl_version),
+        "Force OpenGL version (use '--opengl 210' for OpenGL 2.1 compatibility mode)")
+      ("disable-anti-aliasing", "Prevent rviz from trying to use anti-aliasing when rendering.")
+      ("no-stereo", "Disable the use of stereo rendering.")("verbose,v", "Enable debug visualizations")
+      ("log-level-debug", "Sets the ROS logger level to debug.");
+    // clang-format on
     po::variables_map vm;
     try
     {
@@ -177,8 +181,8 @@ bool VisualizerApp::init(int argc, char** argv)
 
     if (!ros::master::check())
     {
-      WaitForMasterDialog* dialog = new WaitForMasterDialog;
-      if (dialog->exec() != QDialog::Accepted)
+      WaitForMasterDialog dialog;
+      if (dialog.exec() != QDialog::Accepted)
       {
         return false;
       }
@@ -223,6 +227,8 @@ bool VisualizerApp::init(int argc, char** argv)
 
     load_config_service_ =
         private_nh.advertiseService("load_config", &VisualizerApp::loadConfigCallback, this);
+    load_config_discarding_service_ = private_nh.advertiseService(
+        "load_config_discarding_changes", &VisualizerApp::loadConfigDiscardingCallback, this);
     save_config_service_ =
         private_nh.advertiseService("save_config", &VisualizerApp::saveConfigCallback, this);
 
@@ -273,6 +279,20 @@ bool VisualizerApp::loadConfigCallback(rviz::SendFilePathRequest& req, rviz::Sen
   return true;
 }
 
+bool VisualizerApp::loadConfigDiscardingCallback(rviz::SendFilePathRequest& req,
+                                                 rviz::SendFilePathResponse& res)
+{
+  fs::path path = req.path.data;
+  if (fs::is_regular_file(path))
+  {
+    bool discard_changes = true;
+    res.success = frame_->loadDisplayConfigHelper(path.string(), discard_changes);
+  }
+  else
+    res.success = false;
+  return true;
+}
+
 bool VisualizerApp::saveConfigCallback(rviz::SendFilePathRequest& req, rviz::SendFilePathResponse& res)
 {
   res.success = frame_->saveDisplayConfig(QString::fromStdString(req.path.data));
