@@ -49,7 +49,7 @@ public:
   virtual PanelDockWidget* addPane(const QString& name,
                                    QWidget* pane,
                                    Qt::DockWidgetArea area = Qt::LeftDockWidgetArea,
-                                   bool floating = true) = 0;
+                                   bool floating = false) = 0;
 
   /** Set the message displayed in the status bar */
   virtual void setStatus(const QString& message) = 0;
