@@ -152,7 +152,11 @@ void YamlConfigWriter::writeConfigNode(const Config& config, YAML::Emitter& emit
     break;
   }
   default:
+// Workaround as YAML::Null is missing from Windows DLLs;
+// see https://github.com/jbeder/yaml-cpp/issues/950
+#ifndef _WIN32
     emitter << YAML::Null;
+#endif
     break;
   }
 }
