@@ -38,10 +38,12 @@ import tf2_ros
 import tf_conversions as tf
 from geometry_msgs.msg import TransformStamped, Vector3
 
-publisher_cov = rospy.Publisher( 'pose_with_cov', PoseWithCovarianceStamped, queue_size=5 )
-publisher_pose = rospy.Publisher( 'pose', PoseStamped, queue_size=5 )
+publisher_cov = rospy.Publisher(
+    "pose_with_cov", PoseWithCovarianceStamped, queue_size=5
+)
+publisher_pose = rospy.Publisher("pose", PoseStamped, queue_size=5)
 
-rospy.init_node( 'test_covariance' )
+rospy.init_node("test_covariance")
 
 br = tf2_ros.TransformBroadcaster()
 rate = rospy.Rate(100)
@@ -66,34 +68,40 @@ while not rospy.is_shutdown():
     pose_with_cov.pose.pose.position.z = 3
 
     ori = pose_with_cov.pose.pose.orientation
-    ori.x, ori.y, ori.z, ori.w = tf.transformations.quaternion_from_euler(pi/2,pi/3,0)
+    ori.x, ori.y, ori.z, ori.w = tf.transformations.quaternion_from_euler(
+        pi / 2, pi / 3, 0
+    )
 
-    pose_with_cov.pose.covariance[0] = linear_deviation**2.0
-    pose_with_cov.pose.covariance[6+1] = 0.0001
-    pose_with_cov.pose.covariance[12+2] = 0.0001
-    pose_with_cov.pose.covariance[18+3] = 0.01
-    pose_with_cov.pose.covariance[24+4] = 0.01
-    pose_with_cov.pose.covariance[30+5] = 0.01
+    pose_with_cov.pose.covariance[0] = linear_deviation ** 2.0
+    pose_with_cov.pose.covariance[6 + 1] = 0.0001
+    pose_with_cov.pose.covariance[12 + 2] = 0.0001
+    pose_with_cov.pose.covariance[18 + 3] = 0.01
+    pose_with_cov.pose.covariance[24 + 4] = 0.01
+    pose_with_cov.pose.covariance[30 + 5] = 0.01
 
     # Define a dynamic pose that should move inside the deviation
     pose = PoseStamped()
     pose.header.frame_id = "base_link"
     pose.header.stamp = stamp
 
-    pose.pose.position.x = pose_with_cov.pose.pose.position.x + linear_deviation*cos( 10 * angle )
+    pose.pose.position.x = pose_with_cov.pose.pose.position.x + linear_deviation * cos(
+        10 * angle
+    )
     pose.pose.position.y = pose_with_cov.pose.pose.position.y
     pose.pose.position.z = pose_with_cov.pose.pose.position.z
 
     ori = pose.pose.orientation
-    ori.x, ori.y, ori.z, ori.w = tf.transformations.quaternion_from_euler(pi/2,pi/3,0)
+    ori.x, ori.y, ori.z, ori.w = tf.transformations.quaternion_from_euler(
+        pi / 2, pi / 3, 0
+    )
 
-    publisher_cov.publish( pose_with_cov )
-    publisher_pose.publish( pose )
+    publisher_cov.publish(pose_with_cov)
+    publisher_pose.publish(pose)
 
     t = TransformStamped()
-    t.header.frame_id = 'base_link'
+    t.header.frame_id = "base_link"
     t.header.stamp = stamp
-    t.child_frame_id = 'pose'
+    t.child_frame_id = "pose"
 
     if 0:
         t.transform.translation = Vector3(radius * cos(angle), radius * sin(angle), 0)
@@ -104,7 +112,7 @@ while not rospy.is_shutdown():
         t.transform.rotation = pose_with_cov.pose.pose.orientation
         br.sendTransform(t)
 
-    angle += .0005
+    angle += 0.0005
     # r = angle
     # p = angle
     # y = angle
